"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const child_process = require("child_process");
const path = require("path");
const fs = require("fs-extra");
function generatePrivateKey() {
    return __awaiter(this, void 0, void 0, function* () {
        const privateKeyPath = path.resolve(process.cwd(), './keys/auth.key');
        const alreadyExists = yield fs.pathExists(privateKeyPath);
        if (alreadyExists) {
            return privateKeyPath;
        }
        return new Promise((resolve, reject) => {
            child_process.exec(`openssl genrsa -aes256 -passout pass:ilovesushi -out ${privateKeyPath} 2048`, (err, priv, stderr) => {
                if (err) {
                    reject(err);
                }
                else {
                    resolve(privateKeyPath);
                }
            });
        });
    });
}
function exportPublicRSAKey(privateKeyPath) {
    return __awaiter(this, void 0, void 0, function* () {
        const publicKeyPath = path.resolve(process.cwd(), './keys/auth.pub');
        const alreadyExists = yield fs.pathExists(publicKeyPath);
        if (alreadyExists) {
            return publicKeyPath;
        }
        return new Promise((resolve, reject) => {
            child_process.exec(`openssl rsa -in ${privateKeyPath} -outform PEM -pubout -out ${publicKeyPath}`, (err, priv, stderr) => {
                if (err) {
                    reject(err);
                }
                else {
                    resolve(publicKeyPath);
                }
            });
        });
    });
}
function setupKeys() {
    return __awaiter(this, void 0, void 0, function* () {
        const keysPath = path.resolve(process.cwd(), './keys/');
        if (!(yield fs.pathExists(keysPath))) {
            yield fs.mkdir(keysPath);
        }
        const privateKeyPath = yield generatePrivateKey();
        const publicKeyPath = yield exportPublicRSAKey(privateKeyPath);
    });
}
exports.setupKeys = setupKeys;
//# sourceMappingURL=autokeygen.js.map